PHP大規模開発入門 第12回
========================

『オートローディング(仮)』のサンプルコードです。PHPと[Composer](https://getcomposer.org/)を導入することで、実際に動作させることが可能です。

Composerのオートローダーを使った簡単なPHPプロジェクトの例になっています。

## インストール

### Composer

Composerを導入していない場合は https://getcomposer.org/doc/00-intro.md に従ってComposerをインストールしてください。

`composer`コマンドが利用可能になったら、コマンドラインでこのディレクトリに移動して以下のコマンドを実行してください。

```
composer install
```

## ディレクトリ構成

`composer install`後は、以下のようなディレクトリ構成になります。

```
.
├── README.md
├── bin
│   └── shell.php
├── composer.json
├── composer.lock
├── legacy_autoloader.php
├── legacy_lib
│   └── Util
│       └── Validate.php
├── lib
│   └── disorder_klass.php
├── phpunit.xml.dist
├── public
│   └── index.php
├── src
│   ├── Model
│   │   └── User.php
│   └── functions.php
├── tests
│   └── DisOrderTest.php
└── vendor
    ├── autoload.php
    ├ …
394 directories, 2036 files
```

`composer.json`の設定で、`./src`以下は **PSR-4**、`./lib`以下は **classmap** を設定しています。

* `lib`は名前空間を利用しているがPSR-4に則っていないライブラリです。`composer.json`のclassmap設定でオートローディング対象に設定されています。
* `legacy_lib`はPSR-0にもPSR-4にも則っていない、プロジェクト固有のライブラリです。`legacy_autoloader.php`によって読み込まれるようになっています。

## 動作確認

### テスト

```sh
composer test

# または

php ./vendor/bin/phpunit
```

### Webサーバーを起動

Composerとオートローディングを使った簡単なWebアプリケーションのサンプルです。

```sh
cd public
php -S localhost:3939 index.php
```

ターミナルで上記のコマンドを実行した状態で、ブラウザで http://localhost:3939/ を開いてください。こちらは初期状態でエラーが発生するようになっていますので、動作させるためには本文の内容を参考に `public/index.php` を修正してみてください。

### 対話環境

```
./bin/shell
```

対話環境(REPL)を利用することで、PHPの機能を気軽に試すことができます。既にオートローディングの設定がされていますので、特に設定なく利用できます。

```
$user = new \WebDB91\Sample\Model\User('Hatsune Miku')
Util_Validate::isIntOrIntegerString('123')

```
